#node-static-asset

node-static-asset is *the best* static asset manager for Node.JS, designed for use with Express, Jade,
Stylus, and Browserify. This project aims to solve all application deployment problems. No thinking
required.

## Install

`npm install static-asset`

...and done.

## Basic Usage

Usually, this should be good enough to get started. Stylus, CSS, Jade templates, and client-side
JavaScript are automatically handled for you.

```javascript
var app = require('express').createServer();
var asset = require('static-asset');
asset.configure('development', asset.defaultConfig.development);
asset.configure('production', asset.defaultConfig.production);
app.use(asset.middleware);
```

## Default Configuration

By default, static-asset does the following:

* Development Environment
	* When applicable, all files are compiled with debugging information, uncompressed
* Production Environment
	* When applicable, all files are minified and compiled without debugging information
* .css and .styl files are rendered using Stylus
* .jade files are compiled and written to *.js files
* .coffee files are compiled to *.js files
* Assumes the following directory structure for your project:
	project/
		/server
			The location of app.js
		/client
			All client-side .js and .coffee files
			/lib
				Client-side libraries
		/views
			.jade and .html files are in here
		/stylus
			.styl and .css source files are in here
		/public
			All of the content publicly available to the WWW
			/images
				Contains all of your images (png, jpeg, gif, bmp, etc.)
			/css
				This dir is generated by static-asset and can be wiped at any time!
			/js
				This dir is generated by static-asset and can be wiped at any time!
			/abcdef
				This directory will never be touched. It's safe to put files in /static

## Advanced Usage

```javascript
var app = require('express').createServer();
var asset = require('static-asset');
var stylus = require('stylus');
var jade = require('jade');

asset.configure(function() {
	//Environment-specific configuration goes here... 'this' refers to 'asset'
	
	//CSS
	this.register(['styl', 'css'], function(body, filename, cb) {
		//'this' still refers to 'asset'
		stylus(body, this.get('stylus'))
			.set('filename', filename)
			.set('compress',  || true)
			.include(__dirname + '/../css/')
			.import(__dirname + '/../css/mixins.styl')
			.import(__dirname + '/../css/colors.styl')
			.render(cb);
	});
	
	//Jade views
	this.register('jade', function(body, filename, cb) {
		var opts = asset.get('jade');
		opts.filename = filename;
		opts.client = true;
		try {
			var fn = jade.compile(body, opts);
			cb(null, fn.toString() );
		} catch(e) {
			cb(e);
		}
	});
	
	//JavaScript
	
	
	//Error-handling
	this.on('error', function(err) {
		//Do something about some error
		console.log('This asset is being an ' + "asset".substring(0, 3) + ':', err.filename);
	});
});

asset.configure('development', function() {
	//Put your development-specific config here...
	this.set('stylus', {
		'compress': false,
		'warn': true,
		'linenos': true
	});
	this.set('jade', {
		'debug': true,
		'compileDebug': true
	});
});
asset.configure('production', function() {
	this.set('jade', {
		'compileDebug': false
	});
});

app.use(asset.middleware);
```
